@@ -5,7 +5,7 @@ use warnings;
 package Hash::Ordered;
 # ABSTRACT: A fast, pure-Perl ordered hash class
 
-our $VERSION = '0.010';
+our $VERSION = '0.012';
 
 use Carp ();
 
@@ -390,7 +390,7 @@ sub shift {
 sub merge {
     my $self = CORE::shift;
     while (@_) {
-        my ( $k, $v ) = splice( @_, -2, 2 );
+        my ( $k, $v ) = splice( @_, 0, 2 );
         if ( !exists $self->[_DATA]{$k} ) {
             my $size = CORE::push @{ $self->[_KEYS] }, "$k"; # stringify key
             $self->[_INDX]{$k} = $size - 1 if $self->[_INDX];
@@ -644,7 +644,7 @@ sub FIRSTKEY {
 }
 
 sub NEXTKEY {
-    return $_[0]->[_ITER]->();
+    return defined( $_[0]->[_ITER] ) ? $_[0]->[_ITER]->() : undef;
 }
 
 sub SCALAR {
@@ -668,7 +668,7 @@ Hash::Ordered - A fast, pure-Perl ordered hash class
 
 =head1 VERSION
 
-version 0.010
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -1185,7 +1185,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Benct Philip Jonsson David Golden Mario Roy
+=for stopwords Benct Philip Jonsson Mario Roy
 
 =over 4
 
@@ -1195,10 +1195,6 @@ Benct Philip Jonsson <bpjonsson@gmail.com>
 
 =item *
 
-David Golden <xdg@xdg.me>
-
-=item *
-
 Mario Roy <marioeroy@gmail.com>
 
 =back
